@@ -14,7 +14,7 @@ except:
 import youtubeservice
 import cutetubewindows
 from cutetubeconfig import *
-from videosharing import Twitter
+from videosharing import Twitter, Facebook
 from Ui_addtoplaylistdialog import Ui_AddToPlaylistDialog
 from Ui_newplaylistdialog import Ui_NewPlaylistDialog
 from Ui_confirmdeletedialog import Ui_ConfirmDeleteDialog
@@ -40,7 +40,6 @@ class AddToPlaylistDialog(QDialog, Ui_AddToPlaylistDialog):
         """
         QDialog.__init__(self, parent)
         self.setupUi(self)
-        self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
         self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged)
         self.videos = videos
         self.yt = youtubeservice.YouTubePlaylistFeed(self)
@@ -121,7 +120,6 @@ class NewPlaylistDialog(QDialog, Ui_NewPlaylistDialog):
         """
         QDialog.__init__(self, parent)
         self.setupUi(self)
-        self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
         self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged)
         self.titleEdit.setFocus()
         self.videos = videos
@@ -338,7 +336,6 @@ class ConfirmDeleteDialog(QDialog, Ui_ConfirmDeleteDialog):
         """
         QDialog.__init__(self, parent)
         self.setupUi(self)
-        self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
         self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged)
         self.confirmLabel.viewport().setAutoFillBackground(False)
         self.confirmLabel.setText("Do you want to delete \'%s\'?" % unicode(title, "utf-8"))
@@ -378,11 +375,6 @@ class RateVideoDialog(QDialog, Ui_RateVideoDialog):
         """
         QDialog.__init__(self, parent)
         self.setupUi(self)
-        try:
-            self.setAttribute(Qt.WA_Maemo5StackedWindow)
-            self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
-        except:
-            pass
         self.videoId = videoId
         for num in range(5):
             item = QListWidgetItem()
@@ -417,11 +409,6 @@ class AddCommentDialog(QDialog, Ui_AddCommentDialog):
         QDialog.__init__(self, parent)
         self.setupUi(self)
         self.commentEdit.setFocus()
-        try:
-            self.setAttribute(Qt.WA_Maemo5StackedWindow)
-            self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
-        except:
-            pass
         self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged)
         self.orientationChanged()
         self.video = video
@@ -467,17 +454,13 @@ class SearchDialog(QDialog, Ui_searchDialog):
         """
         QDialog.__init__(self, parent)
         self.setupUi(self)
+        self.setAttribute(Qt.WA_Maemo5StackedWindow) 
         self.username = username
         if self.username != None:
             if self.username == youtubeservice.YouTubeDataService.currentUser:
                 self.setWindowTitle("Search my uploads")
             else:
                 self.setWindowTitle("Search %s\'s videos" % unicode(self.username, "utf-8"))
-        try:
-            self.setAttribute(Qt.WA_Maemo5StackedWindow)
-            self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
-        except:
-            pass
         self.searchOrderButton = QMaemo5ValueButton("Order results by:", self)
         self.searchOrderButton.setValueLayout(QMaemo5ValueButton.ValueUnderTextCentered)
         self.searchOrderModel = QStandardItemModel(0, 1)
@@ -490,7 +473,7 @@ class SearchDialog(QDialog, Ui_searchDialog):
         self.searchOrderSelector.setModel(self.searchOrderModel)
         self.searchOrderButton.setPickSelector(self.searchOrderSelector)
         self.searchOrderSelector.setCurrentIndex(SearchSettings.searchOrder)
-        self.recentSearchesButton = QMaemo5ValueButton("Recent Searches", self)
+        self.recentSearchesButton = QMaemo5ValueButton("Recent searches", self)
         self.recentSearchesButton.setValueLayout(QMaemo5ValueButton.ValueUnderTextCentered)
         self.recentSearchesModel = QStandardItemModel(0, 1)
         for searchString in SearchSettings.recentSearches:
@@ -550,9 +533,9 @@ class SearchDialog(QDialog, Ui_searchDialog):
         else:
             if searchString in SearchSettings.recentSearches:
                 SearchSettings.recentSearches.removeAll(searchString)
-                if SearchSettings.recentSearches.count() > 30:
-                    SearchSettings.recentSearches.removeAt(30)
-                SearchSettings.recentSearches.prepend(searchString)
+            if SearchSettings.recentSearches.count() > 30:
+                SearchSettings.recentSearches.removeAt(30)
+            SearchSettings.recentSearches.prepend(searchString)
             searchWindow = cutetubewindows.SearchResultsWindow(self, searchString, searchOrder, self.username)
         
     
@@ -569,13 +552,12 @@ class SettingsDialog(QDialog):
         QDialog.__init__(self, parent)
         #self.resize(800, 450)
         self.setWindowTitle("Settings")
-        self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
         self.saveButton = QPushButton("Save",  self)
-        accountLabel = QLabel("YouTube Accounts")
+        accountLabel = QLabel("YouTube accounts")
         accountLabel.setStyleSheet("color: rgb(120, 120, 120)")
-        playerLabel = QLabel("Video Playback Options")
+        playerLabel = QLabel("Video playback options")
         playerLabel.setStyleSheet("color: rgb(120, 120, 120)")
-        downloadsLabel = QLabel("Video Download Options")
+        downloadsLabel = QLabel("Video download options")
         downloadsLabel.setStyleSheet("color: rgb(120, 120, 120)")
         self.accountButton = QMaemo5ValueButton("Default account", self)
         self.accountButton.setValueLayout(QMaemo5ValueButton.ValueUnderText)
@@ -622,9 +604,26 @@ class SettingsDialog(QDialog):
         self.downloadFormatButton.setPickSelector(self.downloadFormatSelector)
         downloadFormat = VideoDownloadSettings.downloadFormat
         self.downloadFormatSelector.setCurrentIndex(VideoDownloadSettings.formatList.index(downloadFormat))
-        self.searchesLabel = QLabel("Youtube Searches")
-        self.searchesLabel.setStyleSheet("color: rgb(120, 120, 120)")
+        searchesLabel = QLabel("Youtube searches")
+        searchesLabel.setStyleSheet("color: rgb(120, 120, 120)")
         self.clearSearchesButton = QPushButton("Clear recent searches", self)
+        generalLabel = QLabel("General settings")
+        generalLabel.setStyleSheet("color: rgb(120, 120, 120)")
+        self.orientationModel = QStandardItemModel(0, 1)
+        for orientation in ("Landscape", "Automatic"):
+            item = QStandardItem(orientation)
+            item.setEditable(False)
+            item.setTextAlignment(Qt.AlignCenter)
+            self.orientationModel.appendRow(item)
+        self.orientationSelector = QMaemo5ListPickSelector()
+        self.orientationSelector.setModel(self.orientationModel)
+        if not GeneralSettings.autoOrientation:
+            self.orientationSelector.setCurrentIndex(0)
+        else:
+            self.orientationSelector.setCurrentIndex(1)
+        self.orientationButton = QMaemo5ValueButton("Display orientation", self)
+        self.orientationButton.setValueLayout(QMaemo5ValueButton.ValueUnderText)
+        self.orientationButton.setPickSelector(self.orientationSelector)
         self.scrollArea = QScrollArea(self)
         self.scrollArea.setMaximumHeight(460)
         self.scrollArea.setFixedWidth(620)
@@ -639,8 +638,10 @@ class SettingsDialog(QDialog):
         vBox.addWidget(self.downloadFolderButton)
         vBox.addWidget(self.downloadFormatButton)
         vBox.addWidget(self.downloadStatusCheckBox)
-        vBox.addWidget(self.searchesLabel)
+        vBox.addWidget(searchesLabel)
         vBox.addWidget(self.clearSearchesButton)
+        vBox.addWidget(generalLabel)
+        vBox.addWidget(self.orientationButton)
         self.scrollArea.setWidget(scrollWidget)
         vBox = QVBoxLayout(self)
         vBox.addWidget(self.scrollArea)
@@ -659,12 +660,12 @@ class SettingsDialog(QDialog):
         screenGeometry = QApplication.desktop().screenGeometry()
         if screenGeometry.height() > screenGeometry.width():
             self.resize(480,  720)
-            for button in (self.accountButton, self.playbackFormatButton, self.downloadFolderButton, self.downloadFormatButton, self.downloadStatusCheckBox, self.clearSearchesButton):
+            for button in (self.accountButton, self.playbackFormatButton, self.downloadFolderButton, self.downloadFormatButton, self.downloadStatusCheckBox, self.clearSearchesButton, self.orientationButton):
                 button.setFixedWidth(420)
             self.saveButton.setGeometry(QRect(10,  620,  460,  70))
         else:
             self.resize(800,  400)
-            for button in (self.accountButton, self.playbackFormatButton, self.downloadFolderButton, self.downloadFormatButton, self.downloadStatusCheckBox, self.clearSearchesButton):
+            for button in (self.accountButton, self.playbackFormatButton, self.downloadFolderButton, self.downloadFormatButton, self.downloadStatusCheckBox, self.clearSearchesButton, self.orientationButton):
                 button.setFixedWidth(580)
             self.saveButton.setGeometry(QRect(640,  300,  150,  70))
         
@@ -701,8 +702,10 @@ class SettingsDialog(QDialog):
             VideoDownloadSettings.defaultTaskStatus = "queued"
         else:
             VideoDownloadSettings.defaultTaskStatus = "paused"
+        GeneralSettings.autoOrientation = (self.orientationSelector.currentIndex() == 1)
+        self.emit(SIGNAL("autoOrientationChanged()"))
         QMaemo5InformationBox.information(self,  "Your settings have been saved")
-        self.close()
+        self.accept()
         
 class AboutDialog(QDialog, Ui_AboutDialog):
     """
@@ -714,7 +717,6 @@ class AboutDialog(QDialog, Ui_AboutDialog):
         """
         QDialog.__init__(self, parent)
         self.setupUi(self)
-        self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
         self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged)
         self.orientationChanged()
         self.label.setPixmap(QPixmap(":/images/ui-images/cutetubehires.png"))
@@ -746,7 +748,7 @@ class AboutDialog(QDialog, Ui_AboutDialog):
         Opens my webpage in the default browser.
         """
         os.system("dbus-send --system --type=method_call --dest=com.nokia.osso_browser /com/nokia/osso_browser/request com.nokia.osso_browser.load_url string:'http://marxianthecoder.blogspot.com'")
-        self.close()
+        self.accept()
     
     @pyqtSignature("")
     def on_donateButton_clicked(self):
@@ -754,7 +756,7 @@ class AboutDialog(QDialog, Ui_AboutDialog):
         Gimme your $$$$!
         """
         os.system("dbus-send --system --type=method_call --dest=com.nokia.osso_browser /com/nokia/osso_browser/request com.nokia.osso_browser.load_url string:'https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=stuhowarth77%40gmail%2ecom&lc=GB&item_name=cuteTube&currency_code=USD&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted'")
-        self.close()
+        self.accept()
 
 class SwitchAccountDialog(QDialog, Ui_SwitchAccountDialog):
     """
@@ -766,7 +768,6 @@ class SwitchAccountDialog(QDialog, Ui_SwitchAccountDialog):
         """
         QDialog.__init__(self, parent)
         self.setupUi(self)
-        self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
         for username in YouTubeAPISettings.userDict.iterkeys():
             item = QListWidgetItem(username)
             item.setTextAlignment(Qt.AlignCenter)
@@ -798,7 +799,6 @@ class AddAccountDialog(QDialog, Ui_AddAccountDialog):
         """
         QDialog.__init__(self, parent)
         self.setupUi(self)
-        self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
         self.orientationChanged()
         self.passwordEdit.setEchoMode(QLineEdit.Password)
         self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged)
@@ -859,7 +859,6 @@ class ManageAccountsDialog(QDialog, Ui_ManageAccountsDialog):
         """
         QDialog.__init__(self, parent)
         self.setupUi(self)
-        self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
         self.orientationChanged()
         self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged)
         for username in YouTubeAPISettings.userDict.iterkeys():
@@ -947,7 +946,6 @@ class EditAccountDialog(QDialog, Ui_EditAccountDialog):
         """
         QDialog.__init__(self, parent)
         self.setupUi(self)
-        self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
         self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged)
         self.usernameEdit.setText(username)
         loginInfo = YouTubeAPISettings.userDict.get(username)
@@ -1020,7 +1018,6 @@ class NoAccountFoundDialog(QDialog,  Ui_NoAccountFoundDialog):
         """
         QDialog.__init__(self, parent)
         self.setupUi(self)
-        self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
         self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged)
         self.orientationChanged()
         self.show()
@@ -1057,70 +1054,6 @@ class NoAccountFoundDialog(QDialog,  Ui_NoAccountFoundDialog):
         in YouTubeDataService to False.
         """
         YouTubeAPISettings.raiseNoAccountFoundDialog = False
-        
-class ShareVideoDialog(QDialog):
-    """
-    Dialog presenting the user with the available video sharing options.
-    """
-    def __init__(self, parent, videoUrl):
-        """
-        Constructor
-        """
-        QDialog.__init__(self, parent)
-        self.setWindowTitle("Share This Video")
-        self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
-        self.videoUrl = videoUrl
-        self.clipboardButton = QPushButton(QIcon(":/images/ui-images/clipboardicon.png"), "Copy to clipboard", self)
-        self.twitterButton = QPushButton(QIcon(":/images/ui-images/twittericon.png"), "Share via twitter", self)
-        self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged)
-        self.orientationChanged()
-        self.connect(self.clipboardButton, SIGNAL("clicked()"), self.copyToClipboard)
-        self.connect(self.twitterButton, SIGNAL("clicked()"), self.shareViaTwitter)
-        self.show()
-        
-    def orientationChanged(self):
-        """
-        Re-orders the widgets when the application 
-        is in portrait mode.
-        """
-        screenGeometry = QApplication.desktop().screenGeometry()
-        if screenGeometry.height() > screenGeometry.width():
-            self.resize(480, 170)
-            self.clipboardButton.setGeometry(QRect(10, 10, 460, 70))
-            self.twitterButton.setGeometry(QRect(10, 90, 460, 70))
-        else:
-            self.resize(800, 90)
-            self.clipboardButton.setGeometry(QRect(10, 10, 300, 70))
-            self.twitterButton.setGeometry(QRect(490, 10, 300, 70))
-            
-    def toggleBusy(self, isBusy = False):
-        """
-        Shows the progress indicator if argument is True, 
-        and hides it otherwise.
-        """
-        self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, isBusy)
-            
-    def copyToClipboard(self):
-        """
-        Copies the video URL to the clipboard.
-        """
-        clipboard = QApplication.clipboard()
-        clipboard.setText(self.videoUrl)
-        QMaemo5InformationBox.information(self, "Video URL copied")
-        self.accept()
-        
-    def shareViaTwitter(self):
-        """
-        Raises a ShareViaTwitterDialog.
-        """
-        self.toggleBusy(True)
-        if not VideoSharingSettings.raiseTwitterAuthorisationDialog:
-            shareViaTwitterDialog = ShareViaTwitterDialog(self, self.videoUrl)
-            self.connect(shareViaTwitterDialog, SIGNAL("accepted()"), self.accept)
-        else:
-            twitterAuthorisationDialog = TwitterAuthorisationDialog(self)
-            self.connect(twitterAuthorisationDialog, SIGNAL("accepted()"), self.shareViaTwitter)
-        self.toggleBusy(False)
 
 class TwitterAuthorisationDialog(QDialog):
     """
@@ -1133,7 +1066,6 @@ class TwitterAuthorisationDialog(QDialog):
         """
         QDialog.__init__(self, parent)
         self.setWindowTitle("Twitter Authorisation")
-        self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
         self.webView = QWebView(self)
         self.webView.setZoomFactor(0.6)
         self.pinLabel = QLabel("Enter pin code", self)
@@ -1219,7 +1151,6 @@ class ShareViaTwitterDialog(QDialog):
         """
         QDialog.__init__(self, parent)
         self.setWindowTitle("Share Via Twitter")
-        self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
         self.messageEdit = QTextEdit(videoUrl, self)
         self.charLabel = QLabel(self)
         self.charLabel.setStyleSheet("color: rgb(120, 120, 120)")
@@ -1279,7 +1210,136 @@ class ShareViaTwitterDialog(QDialog):
                 QMaemo5InformationBox.information(self, "Unable to post message to Twitter")
             self.toggleBusy()
             
+class FacebookAuthorisationDialog(QDialog):
+    """
+    Displays the Facebook web page and a line edit enabling the 
+    user to provide Facebook authorisation.
+    """
+    def __init__(self, parent):
+        """
+        Constructor
+        """
+        QDialog.__init__(self, parent)
+        self.setWindowTitle("Facebook Authorisation")
+        self.webView = QWebView(self)
+        self.submitButton = QPushButton("Done", self)
+        self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged)
+        self.orientationChanged()
+        self.connect(self.submitButton, SIGNAL("clicked()"), self.getFacebookAccess)
+        self.connect(self.webView, SIGNAL("loadFinished(bool)"), self.loadFinished)
+        self.show()
+        self.loadFacebookPage()
         
+    def orientationChanged(self):
+        """
+        Re-orders the widgets when the application 
+        is in portrait mode.
+        """
+        screenGeometry = QApplication.desktop().screenGeometry()
+        if screenGeometry.height() > screenGeometry.width():
+            self.resize(480, 400)
+            self.webView.setGeometry(QRect(10, 10, 460, 300))
+            self.submitButton.setGeometry(QRect(10, 320, 460, 70))
+        else:
+            self.resize(800, 270)
+            self.webView.setGeometry(QRect(10, 10, 590, 250))
+            self.submitButton.setGeometry(QRect(640, 190, 150, 70))
+            
+    def toggleBusy(self, isBusy = False):
+        """
+        Shows the progress indicator if argument is True, 
+        and hides it otherwise.
+        """
+        self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, isBusy)
+        
+    def loadFinished(self):
+        """
+        Removes the progress indicator.
+        """
+        self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, False)
+        
+    def loadFacebookPage(self):
+        """
+        Displays the Facebook authorisation web page in the QWebView.
+        """
+        self.toggleBusy(True)
+        clientId = Facebook.clientId
+        try:
+            url = "https://graph.facebook.com/oauth/authorize?client_id=%s&redirect_uri=http://www.facebook.com/connect/login_success.html&type=user_agent&display=popup&scope=publish_stream,offline_access" % clientId
+            self.webView.load(QUrl(url))
+        except:
+            QMaemo5InformationBox.information(self, "Unable to connect to Facebook")
+            self.toggleBusy()
+            
+    def getFacebookAccess(self):
+        """
+        Retrieves and stores the access token to enable posting of status messages.
+        """
+        self.toggleBusy(True)
+        accessUrl = self.webView.url().toString()
+        try:
+            accessToken = unicode(accessUrl, "utf-8").split("=")[1].split("&")[0] #Had to do this this because QUrl.queryItemValue() wouldn't work.
+            VideoSharingSettings.facebookAccessToken = accessToken
+            QMaemo5InformationBox.information(self, "cuteTube is now authorised to access your Facebook account")
+            VideoSharingSettings.raiseFacebookAuthorisationDialog = False
+            self.accept()
+        except:
+            QMaemo5InformationBox.information(self, "Unable to confirm Facebook authorisation")
+        self.toggleBusy()
+            
+class ShareViaFacebookDialog(QDialog):
+    """
+    Dialog enabling the user to share the video via Twitter.
+    """
+    def __init__(self, parent, videoUrl):
+        """
+        Constructor
+        """
+        QDialog.__init__(self, parent)
+        self.setWindowTitle("Share Via Facebook")
+        self.messageEdit = QTextEdit(videoUrl, self)
+        self.submitButton = QPushButton("Submit", self)
+        self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged)
+        self.orientationChanged()
+        self.connect(self.submitButton, SIGNAL("clicked()"), self.shareViaFacebook)
+        self.show()
+        
+    def orientationChanged(self):
+        """
+        Re-orders the widgets when the application 
+        is in portrait mode.
+        """
+        screenGeometry = QApplication.desktop().screenGeometry()
+        if screenGeometry.height() > screenGeometry.width():
+            self.resize(480, 230)
+            self.messageEdit.setGeometry(QRect(10, 10, 460, 140))
+            self.submitButton.setGeometry(QRect(10, 150, 460, 70))
+        else:
+            self.resize(800, 160)
+            self.messageEdit.setGeometry(QRect(10, 10, 590, 140))
+            self.submitButton.setGeometry(QRect(640, 80, 150, 70))
+            
+    def toggleBusy(self, isBusy = False):
+        """
+        Shows the progress indicator if argument is True, 
+        and hides it otherwise.
+        """
+        self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, isBusy)
+            
+    def shareViaFacebook(self):
+        """
+        Shares the video and accompanying message via Twitter.
+        """
+        message = unicode(self.messageEdit.toPlainText(), "utf-8")
+        if message != "":
+            self.toggleBusy(True)
+            try:
+                Facebook.postMessage(message)
+                QMaemo5InformationBox.information(self, "Your message has been posted to Facebook")
+                self.accept()
+            except:
+                QMaemo5InformationBox.information(self, "Unable to post message to Facebook")
+            self.toggleBusy()
         
 
             
