@@ -15,6 +15,7 @@ import videoinfowindow
 import customwidgets
 import youtubeservice
 import cutetubedialogs
+from cutetubeconfig import GeneralSettings
 from videoplaybackwindow import VideoPlaybackWindow
 
 class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
@@ -27,11 +28,8 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
         """
         QMainWindow.__init__(self, parent)
         self.setupUi(self)
-        try:
-            self.setAttribute(Qt.WA_Maemo5StackedWindow)
-            self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
-        except:
-            pass
+        self.setAttribute(Qt.WA_Maemo5StackedWindow)
+        self.setAttribute(Qt.WA_Maemo5AutoOrientation, GeneralSettings.autoOrientation)
         self.lineFilter = QLineEdit(self.toolBar)
         self.toolBar.addWidget(self.lineFilter)
         closeFilter = QAction(self.toolBar)
@@ -1173,9 +1171,9 @@ class DownloadsWindow(CutetubeWindows):
         CutetubeWindows.__init__(self, parent)
         self.setWindowTitle("Downloads")
         self.actionRemoveFromQueue.setVisible(True)
-        self.actionRemoveFromQueue.setText("Cancel Download")
+        self.actionRemoveFromQueue.setText("Cancel download")
         self.actionClearQueue.setVisible(True)
-        self.actionClearQueue.setText("Clear Downloads")
+        self.actionClearQueue.setText("Clear downloads")
         self.actionPauseDownload.setVisible(True)
         self.actionResumeDownload.setVisible(True)
         self.actionDownloads.setVisible(False)
