@@ -28,17 +28,15 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
         """
         QMainWindow.__init__(self, parent)
         self.setupUi(self)
-        try:
-            self.setAttribute(Qt.WA_Maemo5StackedWindow)  
-            self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
-        except:
-            pass
+        self.restoreSettings()
+        self.setAttribute(Qt.WA_Maemo5StackedWindow) 
+        self.setAutoDisplayOrientation()
         self.youtubeLabel = QLabel(self)
         self.youtubeLabel.setGeometry(QRect(10, 10, 150, 90))
         self.youtubeLabel.setPixmap(QPixmap(":/images/ui-images/youtube.png"))
         self.youtubeLabel.setScaledContents(True)
-        self.orientationChanged()
         self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged)
+        self.orientationChanged()
         self.keyPressEvent = self.showSearchDialog
         for button in (self.myAccountButton, self.mostRecentButton, self.mostViewedButton, self.searchButton):
             button.setStyleSheet("border: 2px solid rgb(120, 120, 120); border-radius: 6px;") 
@@ -51,7 +49,6 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
             self.actionDownloads.setText("Downloads (%s videos)" % unicode(taskQueueLength))
         self.show()
         self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, True)
-        self.restoreSettings()
         self.youtubeLogin()
         
     def changeButtonStyleSheet(self):
@@ -108,6 +105,7 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
         Restores the application settings.
         """
         settings = QSettings()
+        GeneralSettings.autoOrientation = settings.value("autoOrientation", True).toBool()
         YouTubeAPISettings.userDict = settings.value("userDict",  {}).toPyObject()
         YouTubeAPISettings.defaultUser = settings.value("defaultUser",  "").toString()
         YouTubeAPISettings.raiseNoAccountFoundDialog = settings.value("noAccountDialog",  True).toBool()
@@ -117,9 +115,12 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
         VideoDownloadSettings.defaultTaskStatus = settings.value("downloadStatus",  "paused").toString()
         if VideoDownloadSettings.downloadFormat in (17, 18, 34, 35, 22):
             VideoDownloadSettings.downloadFormat = settings.value("downloadFormat",  18).toInt()[0]
+        YouTubeVideoDownloader.restoreTasks(settings.value("downloadTaskQueue", QStringList()).toStringList())
         VideoSharingSettings.raiseTwitterAuthorisationDialog = settings.value("twitterAuthDialog", True).toBool()
         VideoSharingSettings.twitterAccessTokenKey = settings.value("twitterKey", "").toString()
         VideoSharingSettings.twitterAccessTokenSecret = settings.value("twitterSecret", "").toString()
+        VideoSharingSettings.raiseFacebookAuthorisationDialog = settings.value("facebookAuthDialog", True).toBool()
+        VideoSharingSettings.facebookAccessToken = settings.value("facebookToken", "").toString()
         SearchSettings.searchOrder = settings.value("searchOrder",  0).toInt()[0]
         SearchSettings.recentSearches = settings.value("recentSearches", QStringList()).toStringList()
         
@@ -128,6 +129,7 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
         Saves the application settings.
         """
         settings = QSettings()
+        autoOrientation = QVariant(GeneralSettings.autoOrientation)
         userDict = QVariant(YouTubeAPISettings.userDict)
         defaultUser = QVariant(YouTubeAPISettings.defaultUser)
         noAccountDialog = QVariant(YouTubeAPISettings.raiseNoAccountFoundDialog)
@@ -135,11 +137,15 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
         downloadFolder = QVariant(VideoDownloadSettings.downloadFolder)
         downloadStatus = QVariant(VideoDownloadSettings.defaultTaskStatus)
         downloadFormat = QVariant(VideoDownloadSettings.downloadFormat)
+        downloadTaskQueue = QVariant (YouTubeVideoDownloader.saveTasks())
         twitterAuthDialog = QVariant(VideoSharingSettings.raiseTwitterAuthorisationDialog)
         twitterKey = QVariant(VideoSharingSettings.twitterAccessTokenKey)
         twitterSecret = QVariant(VideoSharingSettings.twitterAccessTokenSecret)
+        facebookAuthDialog = QVariant(VideoSharingSettings.raiseFacebookAuthorisationDialog)
+        facebookToken = QVariant(VideoSharingSettings.facebookAccessToken)
         searchOrder = QVariant(SearchSettings.searchOrder)
         recentSearches = QVariant(SearchSettings.recentSearches)
+        settings.setValue("autoOrientation", autoOrientation)
         settings.setValue("userDict", userDict)
         settings.setValue("defaultUser", defaultUser)
         settings.setValue("noAccountDialog", noAccountDialog)
@@ -147,11 +153,20 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
         settings.setValue("downloadStatus", downloadStatus)
         settings.setValue("playbackFormat", playbackFormat)
         settings.setValue("downloadFormat", downloadFormat)
+        settings.setValue("downloadTaskQueue", downloadTaskQueue)
         settings.setValue("twitterAuthDialog", twitterAuthDialog)
         settings.setValue("twitterKey", twitterKey)
         settings.setValue("twitterSecret", twitterSecret)
+        settings.setValue("facebookAuthDialog", facebookAuthDialog)
+        settings.setValue("facebookToken", facebookToken)
         settings.setValue("searchOrder", searchOrder)
         settings.setValue("recentSearches", recentSearches)
+        
+    def setAutoDisplayOrientation(self):
+        """
+        Sets the display orientation of the application.
+        """
+        self.setAttribute(Qt.WA_Maemo5AutoOrientation, GeneralSettings.autoOrientation)
 
     def orientationChanged(self):
         """
@@ -253,6 +268,7 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
         Raises a SettingsDialog.
         """
         settingsDialog = cutetubedialogs.SettingsDialog(self)
+        self.connect(settingsDialog, SIGNAL("autoOrientationChanged()"), self.setAutoDisplayOrientation)
     
     @pyqtSignature("")
     def on_actionDownloads_triggered(self):
