@@ -16,6 +16,7 @@ import cutetubedialogs
 import cutetubewindows
 import youtubeservice
 import customwidgets
+from cutetubeconfig import VideoSharingSettings
 from videoplaybackwindow import VideoPlaybackWindow
 
 class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
@@ -28,13 +29,9 @@ class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
         Constructor
         """
         QMainWindow.__init__(self, parent)
-        try:
-            self.setAttribute(Qt.WA_Maemo5StackedWindow)
-            self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
-            self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged)
-        except:
-            pass
+        self.setAttribute(Qt.WA_Maemo5StackedWindow)
         self.setupUi(self)
+        self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged)
         self.orientationChanged()
         self.descriptionTextBox.viewport().setAutoFillBackground(False)
         self.titleLabel.viewport().setAutoFillBackground(False)
@@ -44,7 +41,7 @@ class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
             self.playlistPosition = position
             self.playlistLength = count
             self.actionEditVideo.setVisible(True)
-            self.actionEditVideo.setText("Edit Custom Metadata")
+            self.actionEditVideo.setText("Edit custom metadata")
         if self.video.author[0].name.text == youtubeservice.YouTubeDataService.currentUser:
             self.actionRateVideo.setVisible(False)
             self.actionUserVideos.setVisible(False)
@@ -70,8 +67,11 @@ class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
             self.commentNumberLabel.setGeometry(QRect(315, 90, 180, 25))
             self.titleLabel.setGeometry(QRect(10, 205, 460, 70))
             self.descriptionTextBox.setGeometry(QRect(10, 275, 460, 295))
-            self.downloadButton.setGeometry(QRect(10, 580, 460, 70))
-            self.playButton.setGeometry(QRect(10, 660, 460, 70))
+            self.clipboardButton.setGeometry(QRect(10, 580, 70, 70))
+            self.facebookButton.setGeometry(QRect(95, 580, 70, 70))
+            self.twitterButton.setGeometry(QRect(180, 580, 70, 70))
+            self.downloadButton.setGeometry(QRect(10, 660, 225, 70))
+            self.playButton.setGeometry(QRect(245, 660, 225, 70))
         else:
             self.titleLabel.setGeometry(QRect(260, 20, 530, 70))
             self.viewsLabel.setGeometry(QRect(10, 260, 50, 30))
@@ -80,16 +80,21 @@ class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
             self.viewsNumberLabel.setGeometry(QRect(70, 260, 180, 25))
             self.commentNumberLabel.setGeometry(QRect(70, 295, 180, 25))
             self.descriptionTextBox.setGeometry(QRect(260, 90, 530, 227))
-            self.downloadButton.setGeometry(QRect(10, 340, 340, 70))
-            self.playButton.setGeometry(QRect(450, 340, 340, 70))
+            self.clipboardButton.setGeometry(QRect(10, 340, 70, 70))
+            self.facebookButton.setGeometry(QRect(95, 340, 70, 70))
+            self.twitterButton.setGeometry(QRect(180, 340, 70, 70))
+            self.downloadButton.setGeometry(QRect(260, 340, 260, 70))
+            self.playButton.setGeometry(QRect(530, 340, 260, 70))
 
     def loadData(self):
         """
         Loads the video data into the appropriate widgets.
         """
+        self.toggleBusy(True)
         self.loadTitleAndDescription()
         self.loadViewsCommentsRating()
         self.loadThumbnail()
+        self.toggleBusy()
 
     def loadTitleAndDescription(self):
         """
@@ -138,7 +143,10 @@ class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
         
         thumbUrl = self.video.media.thumbnail[3].url
         thumbnail = youtubeservice.YouTubeDataService.getVideoThumbnail(thumbUrl)
-        self.thumbLabel.setPixmap(thumbnail) 
+        try:
+            self.thumbLabel.setPixmap(thumbnail) 
+        except:
+            self.thumbLabel.setPixmap(QPixmap(":/images/ui-images/thumbnail.png"))
     
     def playVideo(self, event = None):
         """
@@ -150,7 +158,7 @@ class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
             videoPlaybackWindow = VideoPlaybackWindow(self, video = self.video)
         except:
             QMaemo5InformationBox.information(self, "Unable to play video")
-        self.toggleBusy(False)
+        self.toggleBusy()
 
     def downloadVideo(self):
         videoTitle = self.video.media.title.text
@@ -161,13 +169,50 @@ class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
         except:
             QMaemo5InformationBox.information(self, "Unable to add video to your download queue")
     
-    def toggleBusy(self, isBusy):
+    def toggleBusy(self, isBusy = False):
         """
         Shows the progress indicator and disables the 
         play button if argument is True, and hides it otherwise.
         """
         self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, isBusy)
-        self.playButton.setDisabled(isBusy)
+        
+    @pyqtSignature("")
+    def on_clipboardButton_clicked(self):
+        """
+        Copies the video URL to the clipboard.
+        """
+        videoUrl = self.video.media.player.url.split("&")[0]
+        clipboard = QApplication.clipboard()
+        clipboard.setText(videoUrl)
+        QMaemo5InformationBox.information(self, "Video URL copied")
+        
+    @pyqtSignature("")
+    def on_facebookButton_clicked(self):
+        """
+        Raises a ShareViaFacebookDialog.
+        """
+        self.toggleBusy(True)
+        videoUrl = self.video.media.player.url.split("&")[0]
+        if not VideoSharingSettings.raiseFacebookAuthorisationDialog:
+            shareViaFacebookDialog = cutetubedialogs.ShareViaFacebookDialog(self, videoUrl)
+        else:
+            facebookAuthorisationDialog = cutetubedialogs.FacebookAuthorisationDialog(self)
+            self.connect(facebookAuthorisationDialog, SIGNAL("accepted()"), self.on_facebookButton_clicked)
+        self.toggleBusy()
+        
+    @pyqtSignature("")
+    def on_twitterButton_clicked(self):
+        """
+        Raises a ShareViaTwitterDialog.
+        """
+        self.toggleBusy(True)
+        videoUrl = self.video.media.player.url.split("&")[0]
+        if not VideoSharingSettings.raiseTwitterAuthorisationDialog:
+            shareViaTwitterDialog = cutetubedialogs.ShareViaTwitterDialog(self, videoUrl)
+        else:
+            twitterAuthorisationDialog = cutetubedialogs.TwitterAuthorisationDialog(self)
+            self.connect(twitterAuthorisationDialog, SIGNAL("accepted()"), self.on_twitterButton_clicked)
+        self.toggleBusy()
     
     @pyqtSignature("")
     def on_playButton_clicked(self):
@@ -272,14 +317,6 @@ class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
         playlist to which to add the current video.
         """
         playlistDialog = cutetubedialogs.AddToPlaylistDialog(self, [self.video])
-        
-    @pyqtSignature("")
-    def on_actionShareVideo_triggered(self):
-        """
-        Raises a ShareVideoDialog.
-        """
-        videoUrl = self.video.media.player.url.split("&")[0]
-        shareVideoDialog = cutetubedialogs.ShareVideoDialog(self, videoUrl)
 
     @pyqtSignature("")
     def on_actionEditVideo_triggered(self):
