@@ -16,6 +16,7 @@ except:
 
 import oauth2 as oauth
 import twitter
+import facebook
 from cutetubeconfig import VideoSharingSettings
 
 class Twitter():
@@ -91,9 +92,14 @@ class Facebook():
     clientSecret = "b98565da82716e57255e27fb4bbba0eb"
 
     @staticmethod
-    def getAccessToken():
+    def postMessage(message):
         """
-        Retrieves the access token following user authorisation.
+        Posts the message to the user's Facebook wall.
         """
-        pass
+        try:
+            accessToken = unicode(VideoSharingSettings.facebookAccessToken, "utf-8")
+        except TypeError:
+            accessToken = VideoSharingSettings.facebookAccessToken
+        api = facebook.GraphAPI(accessToken)
+        api.put_object("me", "feed", message = message)
         
