@@ -151,12 +151,15 @@ class YouTubeDataService(object):
         """
         Retrieves and returns the thumbnail for the video.
         """
-        opener = urllib2.build_opener()
-        thumbPage = opener.open(thumbUrl)
-        image = QImage()
-        if image.loadFromData(thumbPage.read()):
-            thumbnail = QPixmap.fromImage(image)
-            return thumbnail
+        try:
+            opener = urllib2.build_opener()
+            thumbPage = opener.open(thumbUrl)
+            image = QImage()
+            if image.loadFromData(thumbPage.read()):
+                thumbnail = QPixmap.fromImage(image)
+        except:
+            thumbnail = None
+        return thumbnail
 
     @staticmethod
     def updateVideo(videoId, newVideoTitle, newVideoDescription):
@@ -236,14 +239,11 @@ class YouTubeVideoFeed(QThread):
             
     def getVideoData(self):
         for video in self.ytVideoFeed.entry:
-            try:
-                thumbnail = YouTubeDataService.getVideoThumbnail(video.media.thumbnail[3].url)
-                videoData = (video, thumbnail)
-                self.videoList.append(video)
-                self.emit(SIGNAL("dataLoaded(PyQt_PyObject)"), videoData)
-                self.results += 1
-            except:
-                pass
+            thumbnail = YouTubeDataService.getVideoThumbnail(video.media.thumbnail[3].url)
+            videoData = (video, thumbnail)
+            self.videoList.append(video)
+            self.emit(SIGNAL("dataLoaded(PyQt_PyObject)"), videoData)
+            self.results += 1
 
     def run(self):
         self.emit(SIGNAL("feedCompleted(bool)"), True)
@@ -380,13 +380,13 @@ class YouTubeVideoDownloader(object):
         object.__init__(self, parent = None)
         
     @staticmethod
-    def addTask(video):
+    def addTask(video, status = VideoDownloadSettings.defaultTaskStatus):
         """
         Add the video to the download queue. 
         """
         task = DownloadTask(video)
         YouTubeVideoDownloader.taskQueue.append(task)
-        if YouTubeVideoDownloader.currentStatus == "inactive" and VideoDownloadSettings.defaultTaskStatus == "queued":
+        if YouTubeVideoDownloader.currentStatus == "inactive" and status == "queued":
             YouTubeVideoDownloader.run()
             
     @staticmethod
@@ -419,6 +419,28 @@ class YouTubeVideoDownloader(object):
         Clears the taskQueue.
         """
         YouTubeVideoDownloader.taskQueue = []
+        
+    @staticmethod
+    def saveTasks():
+        """
+        Saves any incomplete download tasks.
+        """
+        taskList = []
+        for task in YouTubeVideoDownloader.taskQueue:
+            if task.getStatus() in ("paused", "queued", "downloading"):
+                savedTask = task.getId()
+                taskList.append(savedTask)
+        return taskList
+        
+    @staticmethod
+    def restoreTasks(taskList):
+        """
+        Restores any saved tasks.
+        """
+        for task in taskList:
+            videoId = unicode(task, "utf-8")
+            video = YouTubeDataService.getVideoEntry(videoId)
+            YouTubeVideoDownloader.addTask(video, "paused")
     
     @staticmethod
     def run():
@@ -439,6 +461,12 @@ class DownloadTask(QThread):
         
     def getTitle(self):
         return self.video.media.title.text
+        
+    def getId(self):
+        return self.video.media.player.url.split("=") [1].split("&")[0]
+        
+    def getVideo(self):
+        return self.video
 
     def getStatus(self):
         return self.status
@@ -447,23 +475,20 @@ class DownloadTask(QThread):
         if status != self.getStatus:
             self.statusChanged = True
             self.status = status
-            
-    def getUrl(self):
-        return YouTubeDataService.getVideoUrl(self.video)
         
     def removedFromList(self):
         if self.status != "completed":
             os.remove(self.tempname)
 
-    def __init__(self, video):
+    def __init__(self, video, status = VideoDownloadSettings.defaultTaskStatus):
         QThread.__init__(self,  parent = None)
-        self.status = VideoDownloadSettings.defaultTaskStatus
+        self.status = status
         self.statusChanged = True
         self.video = video
         self.connect(self,  SIGNAL("finished()"),  YouTubeVideoDownloader.run)
 
         # Create the target filename
-        if VideoDownloadSettings.downloadFormat in ("34", "35", "22"):
+        if VideoDownloadSettings.downloadFormat in (34, 35, 22):
             formatExt = "HQ"
             self.filename = "%s/%s-%s.mp4" % (VideoDownloadSettings.downloadFolder, unicode(re.sub('[:/|\\\\]', "-", self.video.media.title.text), "utf-8"), formatExt)
         else:
